@@ -14,13 +14,14 @@ fi
 
 
 #installing POT
-if !(git clone -b 2022.1.0 https://github.com/openvinotoolkit/openvino.git) then
-   exit 1
-   echo -e "\e[1;32mgit is failing check with version or with the git link\e[0m"
-else
-    echo -e "\e[1;32mSuccess\e[0m"
-    cd openvino/tools/pot/
-    sudo python3 setup.py install
-    echo -e "\e[1;32mpot is installed\e[0m"
-fi
+# Creating a symbolic link 
+
+ln -s /opt/intel/openvino_2021/deployment_tools/tools/ workload/
+
+echo -e "\e[1;31mSymbolic link created in workloads folder\e[0m"
+
+echo -e "\e[1;32m\nFollow the README.md for usage\e[0m"
+
+
+
 
